## -----------------------------------------------------------------------------
# library(reticulate)
# library(rCISSVAE)
# 
# # Train a model
# res <- run_cissvae(data)
# 
# # Save the trained model to disk
# save_cissvae_model(res$model, "trained_vae.pt")
# 
# # IMPORTANT
# # The Python environment must be active so 'torch' can be imported.

